@@ -1,8 +1,7 @@
-# -*- coding: utf-8 -*-
 ##############################################################################
 #  This file is part of Bioconvert software
 #
-#  Copyright (c) 2017 - Bioconvert Development Team
+#  Copyright (c) 2017-2022 - Bioconvert Development Team
 #
 #  Distributed under the terms of the 3-clause BSD license.
 #  The full license is in the LICENSE file, distributed with this software.
@@ -10,10 +9,8 @@
 #  website: https://github.com/biokit/bioconvert
 #  documentation: http://bioconvert.readthedocs.io
 ##############################################################################
-""" description """
-from bioconvert import ConvBase
-from bioconvert import requires
-
+"""Convert :term:`ABI` format to :term:`FASTA` format"""
+from bioconvert import ConvBase, requires
 
 __all__ = ["ABI2FASTA"]
 
@@ -21,10 +18,15 @@ __all__ = ["ABI2FASTA"]
 class ABI2FASTA(ConvBase):
     """Convert :term:`ABI` file to :term:`FASTQ` file
 
-    Some description.
+    :term:`ABI` files are created by ABI sequencing machine and includes
+    PHRED quality scores for base calls. This allows the creation of
+    :term:`FastA` files.
+
+    Method implemented is based on BioPython [BIOPYTHON]_.
 
     """
 
+    #: Default value
     _default_method = "biopython"
 
     def __init__(self, infile, outfile, *args, **kargs):
@@ -38,8 +40,10 @@ class ABI2FASTA(ConvBase):
 
     @requires(python_library="biopython")
     def _method_biopython(self, *args, **kwargs):
+        """For this method we use the biopython package Bio.SeqIO. 
+        
+        `Bio.SeqIO Documentation <https://biopython.org/docs/1.76/api/Bio.SeqIO.html>`_"""
         from Bio import SeqIO
+
         records = SeqIO.parse(self.infile, "abi")
         SeqIO.write(records, self.outfile, "fasta")
-
-
