@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 ##############################################################################
 #  This file is part of Bioconvert software
 #
@@ -10,7 +9,7 @@
 #  website: https://github.com/biokit/bioconvert
 #  documentation: http://bioconvert.readthedocs.io
 ##############################################################################
-""" description """
+"""Convert :term:`ABI` format to :term:`FASTQ` format"""
 from bioconvert import ConvBase
 from bioconvert import requires
 
@@ -21,10 +20,14 @@ __all__ = ["ABI2FASTQ"]
 class ABI2FASTQ(ConvBase):
     """Convert :term:`ABI` file to :term:`FASTQ` file
 
-    Some description.
+    :term:`ABI` files are created by ABI sequencing machine and includes
+    PHRED quality scores for base calls. This allows the creation
+    of :term:`FastQ` files.
 
+    Method implemented is based on BioPython [BIOPYTHON]_.
     """
 
+    #: Default value
     _default_method = "biopython"
 
     def __init__(self, infile, outfile, *args, **kargs):
@@ -38,8 +41,10 @@ class ABI2FASTQ(ConvBase):
 
     @requires(python_library="biopython")
     def _method_biopython(self, *args, **kwargs):
+        """For this method we use the biopython package Bio.SeqIO.
+
+        `Bio.SeqIO Documentation <https://biopython.org/docs/1.76/api/Bio.SeqIO.html>`_"""
         from Bio import SeqIO
+
         records = SeqIO.parse(self.infile, "abi")
         SeqIO.write(records, self.outfile, "fastq")
-
-
